//+------------------------------------------------------------------+
//|                                                                  |
//|                 Copyright  1999-2008, MetaQuotes Software Corp. |
//|                                         http://www.metaquotes.ru |
//+------------------------------------------------------------------+

//---- indicator settings
#property  indicator_chart_window
#property  indicator_buffers 0

//----

//---- indicator parameters
extern int  timeframe    = 30;
extern int  bars_forward = 5;
extern int  font_size    = 9;

// exported variables
extern string note1 = "----timeframe----";
extern string help1 = "set to true to add timeframe to chart";
extern bool     TF1_HIGH    = true;   // set true to display MA's
extern bool     TF1_LOW     = true;   // set true to display

string ChartTF;
double LastHigh, LastLow;   // used to remember last high and low, no need to redraw if they haven't changed
datetime Bar1Time;          //  used to check if the curen tick is for a new bar

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
   {
   IndicatorShortName("HTF-levels");
   
   ChartTF = GetTimeFrame(timeframe);

   //---- initialization done
   return(0);
   }
     
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
   {
   ObjectDelete("TF1_HIGH");
   ObjectDelete("TF1_HIGH_label");
   ObjectDelete("TF1_LOW");
   ObjectDelete("TF1_LOW_LABEL");
   return(0);
   }

//+------------------------------------------------------------------+
//| Other timeframe line levels                                           |
//+------------------------------------------------------------------+
int start()
   {
//   Comment("");
   if( (iHigh(NULL,timeframe,0) <= LastHigh && iLow(NULL,timeframe,0) >= LastLow ) &&  // only update the objects if they need updating
       iTime(NULL, timeframe, 1) == Bar1Time) return(0);
   
   LastHigh = iHigh(NULL,timeframe,0);
   LastLow  = iLow (NULL,timeframe,0);
   Bar1Time = iTime(NULL, timeframe, 1);
   
//   Comment("Redraw");
   //---- Higher Time Frame (TF1) LEVEL LINES
   //---- bool ObjectCreate(string name, int type, int window, datetime time1, double price1, datetime time2=0,double price2=0, datetime time3=0, double price3=0)
   //---- Time[0] + numberOfSecondsIntoTheFuture is: Time[0]+q*Period()*60; // q bars into the future 
   //----
   if (TF1_HIGH) // draw if true
      {
      if (ObjectFind("TF1_HIGH") == -1) 
         ObjectCreate("TF1_HIGH", OBJ_TREND, 0, 0, 0, 0, 0);
         
      ObjectSet("TF1_HIGH", OBJPROP_TIME1, Time[0] + bars_forward * 60 * Period() );
      ObjectSet("TF1_HIGH", OBJPROP_TIME2, Time[0] + 2 * bars_forward * 60 * Period() );
      
      ObjectSet("TF1_HIGH", OBJPROP_PRICE1, iHigh(NULL,timeframe,0) );
      ObjectSet("TF1_HIGH", OBJPROP_PRICE2, iHigh(NULL,timeframe,0) );
      
      ObjectSet("TF1_HIGH", OBJPROP_RAY, false);
      ObjectSet("TF1_HIGH", OBJPROP_COLOR, Lime);
      ObjectSet("TF1_HIGH",OBJPROP_WIDTH,3);
      }
    
    if (TF1_LOW) // draw if true
      {
      if (ObjectFind("TF1_LOW") == -1) 
         ObjectCreate("TF1_LOW", OBJ_TREND, 0, 0, 0, 0, 0);
      
      ObjectSet("TF1_Low", OBJPROP_TIME1, Time[0] + bars_forward * 60 * Period() );
      ObjectSet("TF1_Low", OBJPROP_TIME2, Time[0] + 2 * bars_forward * 60 * Period() );
      
      ObjectSet("TF1_Low", OBJPROP_PRICE1, iLow(NULL,timeframe,0) );
      ObjectSet("TF1_Low", OBJPROP_PRICE2, iLow(NULL,timeframe,0) );

      ObjectSet("TF1_LOW", OBJPROP_RAY, false);
      ObjectSet("TF1_Low", OBJPROP_COLOR, Lime);
      ObjectSet("TF1_Low",OBJPROP_WIDTH,3);
      }  
   
   // ---- Higher Time Frame (TF1) Line Labels
   if (TF1_HIGH) // draw if true
      {
      if (ObjectFind("TF1_HIGH_label") == -1) 
         ObjectCreate("TF1_HIGH_label", OBJ_TEXT, 0, 0, 0);
      
      ObjectSet("TF1_HIGH_label", OBJPROP_TIME1, Time[0] + bars_forward * 60 * Period() );
      ObjectSet("TF1_HIGH_label", OBJPROP_PRICE1, iHigh(NULL, timeframe, 0) );

      ObjectSet("TF1_HIGH_label", OBJPROP_COLOR, Lime);
      ObjectSetText("TF1_HIGH_label", ChartTF+" HIGH", font_size, "Arial", Lime); 
      }
    
   if (TF1_LOW) // draw if true
      {
      if (ObjectFind("TF1_LOW_label") == -1) 
         ObjectCreate("TF1_LOW_label", OBJ_TEXT, 0, 0, 0);
      
      ObjectSet("TF1_LOW_label", OBJPROP_TIME1, Time[0] + bars_forward * 60 * Period() );
      ObjectSet("TF1_LOW_label", OBJPROP_PRICE1, iLow(NULL, timeframe, 0) );
      
      ObjectSet("TF1_LOW_label", OBJPROP_COLOR, Lime);
      ObjectSetText("TF1_LOW_label", ChartTF+" LOW", font_size, "Arial", Lime); 
      } 
   
   //----
   return(0);
   }
//+------------------------------------------------------------------+

//+---------------------------------------------------------------------+
//| GetTimeFrame function - returns the textual timeframe               |
//+---------------------------------------------------------------------+
string GetTimeFrame(int lPeriod)
   {
      switch(lPeriod)
      {
      case 1: return(StringConcatenate("M", lPeriod));
      case 5: return(StringConcatenate("M", lPeriod));
      case 15: return(StringConcatenate("M", lPeriod)); 
      case 30: return(StringConcatenate("M", lPeriod));
      case 60: return(StringConcatenate("H", lPeriod/60 ));
      case 240: return(StringConcatenate("H", lPeriod/60 ));
      case 1440: return("D1");
      case 10080: return("W1"); 
      case 43200: return("MN1"); 
      }
   
   }
//+---------------------------------------------------------------------+